@@ -52,7 +52,6 @@ class DataBaseWorker:
         self.debug = debug
         self.sql_credentials = sql_credentials
         self.cred = self.sql_credentials[self.db]
-        self.conn = None
         if self.__check_dialect():
             uri_sql_alchemy = "{0}://{1}:{2}@{3}:{4}/{5}".format(
                 self.dialect,
@@ -71,15 +70,10 @@ class DataBaseWorker:
             self.schema = self.cred["schema"]
         else:
             self.schema = self.cred["database"]
-        self.logger.info("try to connect to {}, host {}...".format(self.db, self.cred["host"]))
-        self.conn = self.engine.connect()
-        self.logger.info("connecting to {}, host {} is successful".format(self.db, self.cred["host"]))
 
     def __del__(self):
-        if self.conn is not None:
-            self.logger.info("Connecting to {}, host {} is closed".format(self.db, self.cred["host"]))
-            self.conn.close()
-            self.engine.dispose()
+        self.logger.info("Dispose engine to {}, host:{} is closed".format(self.db, self.cred["host"]))
+        self.engine.dispose()
 
     def __check_dialect(self):
         if self.db not in base_converter_params.keys():
